<?php
use Automattic\WooCommerce\Blocks\Integrations\IntegrationInterface;

	/**
	* Class for integrating with WooCommerce Blocks
	*/
class Koalaaps_Multiple_Customer_Address_Checkout_Blocks_Integration implements IntegrationInterface {

	/**
	 * The name of the integration.
	 *
	 * @return string
	 */
	public function get_name() {
		return 'ka_mca_checkout_block';
	}

	/**
	 * When called invokes any initialization/setup for the integration.
	 */
	public function initialize() {


		$this->register_ka_mca_upload_file_block__block_frontend_scripts();
		$this->register_ka_mca_upload_file_block__block_editor_scripts();
		$this->register_main_integration();

		add_action('wp_enqueue_scripts', array( $this, 'kgr_recaptca_localize' ));
	}


	public function kgr_recaptca_localize() {
		wp_enqueue_script( 'kgr-blocks-frontj', plugins_url( '/src/js/ka-mca-checkout-block/block.js', __FILE__ ), '', '1.1', false );
		wp_enqueue_script( 'jquery' );

		$html = '';
		$card_detail ='';
		$card_info ='';
		$card_billing ='';
		if ( is_user_logged_in() ) {
		global $woocommerce;

		// Get the current post ID safely
		$post_id = get_the_ID();

			if ( $post_id ) {
				$product_id = array();
				$cs_meta_val = get_post_meta($post_id);
				$shipdiffad  =  get_option('Shipping_address');
				$user_id     =  get_current_user_id();
				$select_user_from_switch = get_option('wmsa_user_role');
				$selected_data = (int) get_user_meta($user_id, 'default_billing_meta', true);
				$Design_layout = get_option( 'Design_layout' );
				$customer           = new WC_Customer( $user_id );
				$Design_layout = get_option('Design_layout');

				if ('1' == $shipdiffad) {
					$html .= '<input type="checkbox" id="differentaddress" name="differentaddress" class="mca_checkdo">';
					$html .= '<label for="differentaddress" class="mca_doyo">' . esc_html__('Do you want to ship to multiple addresses?', 'koala-multiple-customer-addresses') . '</label>';
				}

				$html .= '<div id="mca_layout_container">';
				$layout_id = 'popup' === $Design_layout ? 'popup_layout' : 'normal_layout';
				$layout_class = 'popup' === $Design_layout ? 'popup_content' : 'checkout_form';
				$html .= "<div id=\"$layout_id\" class=\"mca_layout " . ( 'popup' === $Design_layout ? 'popup' : '' ) . '">';
				if ( 'popup' === $Design_layout ) {
					$html .= '<span id="close-popup" class="close-btn">&times;</span>';
				}
				$html .= '<form action="" id="checkout_form" class="' . $layout_class . '" method="post">';
				$html .= '<div class="kamca_info">';
				$html .= '<div class="mca_header">';
				$html .= '<div class="mca_pro"><b>' . esc_html__('Product', 'koala-multiple-customer-addresses') . '</b></div>';
				$html .= '<div class="mca_qua"><b>' . esc_html__('Quantity', 'koala-multiple-customer-addresses') . '</b></div>';
				$html .= '<div class="mca_ad"><b>' . esc_html__('Sent To', 'koala-multiple-customer-addresses') . '</b></div>';
				$html .= '</div>';

				$user_id = get_current_user_id();
				$all_shipping = get_user_meta($user_id, 'all_shipping_address', true);
				$select_label = get_option('default_select_key_field');

				foreach (WC()->cart->get_cart() as $cart_item_key => $cart_item) {
					$item = $cart_item['data'];
					$user_selected_address = isset($cart_item['address']) ? $cart_item['address'] : '';

					if (!empty($item)) {
						$quantity = $cart_item['quantity'];
						$product_id = $cart_item['product_id'];
						$product = wc_get_product($product_id);

						if (!empty($product)) {
							$name = $product->get_title();
							$image = $product->get_image();
							$category_id = $product->get_category_ids();
						}

						$html .= '<div class="mca_items mca_items_' . esc_attr($cart_item_key) . '">';
						$html .= '<div class="mca_img">' . wp_kses_post($image) . '</div>';
						$html .= '<div class="mca_nam">' . esc_html__($name, 'koala-multiple-customer-addresses') . '</div>';

						$html .= '<div class="mca">';
						$html .= '<div class="mca_quan" id="mca_quan_' . intval($product_id) . '">';
						$html .= '<input type="number" name="item_multi_address[' . esc_attr($cart_item_key) . '][1][qty]" class="qty" min="0" value="' . intval($quantity) . '">';
						$html .= '</div>';

						$args = array(
							'post_type' => 'ka_content_rule',
							'post_status' => 'publish',
							'numberposts' => -1,
							'orderby' => 'menu_order',
							'order' => 'ASC',
							'fields' => 'ids',
						);
						$get_post_data = get_posts($args);

						$flag_mca = false;
						foreach ($get_post_data as $rules) {
							$pro = get_post_meta($rules, 'kanyp_product_rules', true);
							$cat = get_post_meta($rules, 'kanyp_category_rules', true);

							if (in_array($product_id, $pro) || array_intersect($cat, $category_id)) {
								$flag_mca = true;
								break;
							}
						}

						$html .= '<div class="mca_add" id="mca_add_' . intval($product_id) . '">';
						$html .= '<select class="extra_select" name="item_multi_address[' . esc_attr($cart_item_key) . '][1][address]">';
						$select_label = get_option('default_select_key_field', esc_html__('Select an address', 'koala-multiple-customer-addresses'));
						$select = $user_selected_address == $select_label ? 'selected' : '';
						$html .= '<option ' . $select . ' value="' . esc_attr($select_label) . '">' . esc_attr($select_label) . '</option>';

						foreach ($all_shipping as $key => $value) {
							$address_identifier_shipping = isset($value['address_identifier_shipping']) ? esc_attr($value['address_identifier_shipping']) : 'Unknown';
							$select = $user_selected_address == $address_identifier_shipping ? 'selected' : '';
							$html .= '<option ' . $select . ' value="' . esc_attr($address_identifier_shipping) . '">' . $address_identifier_shipping . '</option>';
						}

						$html .= '</select><br>';
						$html .= '</div>';
						$html .= '</div>';

						$html .= '</div>';
						if ($flag_mca) {
							$html .= '<div class="mca_link"><p>This item can be shipped to the default address only</p></div>';
						} else {
							$html .= '<div class="mca_link" pro_id="' . intval($product_id) . '">';
							$html .= '<input type="hidden" name="pro_id[' . esc_attr($cart_item_key) . '][]" value="' . intval($product_id) . '"><a id="' . intval($product_id) . '" href="" data-cart_item_key="' . esc_attr($cart_item_key) . '" class="mca_chnage_text" value="' . intval($product_id) . '">Ship this item to another address</a>';
							$html .= '</div>';
						}
					}
				}

				$html .= '<input type="submit" name="update" class="update_btn kaama-update_btn">';
				$html .= '</div>';
				$html .= '</form>';
				$html .= '</div>';
				$html .= '</div>';
			} else {
				// Handle the case where post ID is not available
				$html = '<p>' . esc_html__('Post ID is not available.', 'koala-multiple-customer-addresses') . '</p>';
			}
		}

		$select_user_from_switch = get_option('wmsa_user_role');
		$user_id                 = get_current_user_id();
		$selected_data           = (int) get_user_meta($user_id, 'default_shipping_meta', true);
		if (isset($user_id) && 0 !== $user_id) {
			$role = current(wp_get_current_user()->roles);
			if (( is_array($select_user_from_switch) && in_array($role, (array) $select_user_from_switch) ) || ( empty($select_user_from_switch) )) {
				$wmsa_disable_ship = get_option('enable_disable_shipping');
				if ('1' !== $wmsa_disable_ship) {
								$user_id      = get_current_user_id();
								$all_shipping = get_user_meta($user_id, 'all_shipping_address', true);
									$card_detail = ''; // Ensure initialization
					$card_detail .= '<div id="refresh_bill">';
					if (!empty($all_shipping)) {
						$card_detail .= '<h4>';
						$shipping_checkout = get_option('shipping_checkout_heading');
						if (isset($shipping_checkout)) {
							$card_detail .= esc_attr($shipping_checkout);
						}
						$card_detail .= '</h4>';
						$card_detail .= '<div id="find_val_shipping" class="find_val_shipping">';
						$card_detail .= '<input type="hidden" name="user_id" value="' . esc_attr($user_id) . '">';
						$card_detail .= '<select id="onchange_shipping">';
					$select_label = get_option('default_select_key_field');
						if (!empty($select_label)) {
							$card_detail .= '<option>' . esc_html($select_label) . '</option>';
						} else {
							$card_detail .= '<option>' . esc_html__('Select an Address', 'koala-multiple-customer-addresses') . '</option>';
						}

						foreach ($all_shipping as $key => $value) {

						$card_detail .= '<option value="' . esc_attr($key) . '"' . selected($key, $selected_data, false) . '>';
						$card_detail .= esc_html($all_shipping[ $key ]['address_identifier_shipping']);
						$card_detail .= '</option>';
						}
					$card_detail .= '</select><br>';
					$hide_new_check_shipping = get_option('hide_add_new_check_ship');
						if ('1' !== $hide_new_check_shipping) {
							$disable_shipping = get_option('enable_disable_shipping');
							if ('1' !== $disable_shipping) {
								$diable_cap_shipping = get_option('disable_user_add_del_shipping');
								if ('1' !== $diable_cap_shipping) {
									$max_addresses_shipping = get_option('max_num_shipping');
									if (!empty($max_addresses_shipping) && 0 !== $max_addresses_shipping) {
										$all_shiiping_add = get_user_meta($user_id, 'all_shipping_address', true);
										$count            = 0;
										foreach ($all_shiiping_add as $key_t => $value) {
											++$count;
										}
										if ($count < $max_addresses_shipping) {
											$shipping_label = get_option('shipping_title_key_field');
											if (empty($shipping_label)) {
												$shipping_title = __('Add New Shipping Address', 'koala-multiple-customer-addresses');
											} else {
												$shipping_title = $shipping_label;
											}
											$card_detail .= '<a id="add_cart_shipping" class="chk_a_style" name="cart_shipping_model">' . esc_html__($shipping_title, 'koala-multiple-customer-addresses') . '</a>';
										}
									} else {
										$shipping_label = get_option('shipping_title_key_field');
										if (empty($shipping_label)) {
											$shipping_title = __('Add New Shipping Address', 'koala-multiple-customer-addresses');
										} else {
											$shipping_title = $shipping_label;
										}
										$card_detail .= '<a id="add_cart_shipping" class="chk_a_style" name="cart_shipping_model">' . esc_html__($shipping_title, 'koala-multiple-customer-addresses') . '</a>';
									}
								}
							}
						}
					$card_detail .= '</div>';
					} else {
						$hide_new_check_shipping = get_option('hide_add_new_check_ship');
						if ('1' !== $hide_new_check_shipping) {
							$disable_shipping = get_option('enable_disable_shipping');
							if ('1' !== $disable_shipping) {
								$diable_cap_shipping = get_option('disable_user_add_del_shipping');
								if ('1' !== $diable_cap_shipping) {
									$max_addresses_shipping = get_option('max_num_shipping');
									if (!empty($max_addresses_shipping) && 0 !== $max_addresses_shipping) {
										$all_shiiping_add = get_user_meta($user_id, 'all_shipping_address', true);
										$count            = 0;
										if (!empty($all_shiiping_add)) {
											foreach ($all_shiiping_add as $key_t => $value) {
												++$count;
											}
										}
										if ($count < $max_addresses_shipping) {
											$shipping_label = get_option('shipping_title_key_field');
											if (empty($shipping_label)) {
												$shipping_title = __('Add New Shipping Address', 'koala-multiple-customer-addresses');
											} else {
												$shipping_title = $shipping_label;
											}
											$card_detail .= '<a id="add_cart_shipping" class="chk_a_style" name="cart_shipping_model">' . esc_html__($shipping_title, 'koala-multiple-customer-addresses') . '</a>';
										}
									} else {
										$shipping_label = get_option('shipping_title_key_field');
										if (empty($shipping_label)) {
											$shipping_title = __('Add New Shipping Address', 'koala-multiple-customer-addresses');
										} else {
											$shipping_title = $shipping_label;
										}
										$card_detail .= '<a id="add_cart_shipping" class="chk_a_style" name="cart_shipping_model">' . esc_html__($shipping_title, 'koala-multiple-customer-addresses') . '</a>';
									}
								}
							}
						}
					}
				$card_detail .= '</div>';
				}
			}
		}  

	$card_info ='<div id="cart_modal_id_shipping" class="cart_model_class_shipping">';
		$card_info .= '<div class="cart_model_content_shipping">';
		$card_info .= '<span class="cart_m_exit_shipping">&times;</span>';
		$card_info .= '<div class="message"></div>';
		$getidentifier = get_option('disable_identifier_name');
		if ('1' !== $getidentifier) {
			$card_info .= '<div class="wms-row">';
			$card_info .= '<div class="wms-col-12">';
			$card_info .= '<label class="mylabel">' . esc_html__('Identifier / Name', 'koala-multiple-customer-addresses') . '</label>';
			$card_info .= '<span class="required">*</span>';
			$card_info .= '<input placeholder="' . esc_html__('Office address', 'koala-multiple-customer-addresses') . '" class="inputsize" type="text" id="identifier_name_shipping" name="identifier_name_shipping">';
			$card_info .= '</div>';
			$card_info .= '</div>';
		}
		$card_info .= '<div class="wms-row">';
		$card_info .= '<div class="wms-col-6">';
		$card_info .= '<label class="mylabel">' . esc_html__('First Name', 'koala-multiple-customer-addresses') . '<span class="required">*</span></label>';
		$card_info .= '<input class="name_size" type="text" name="first_name_shipping">';
		$card_info .= '</div>';
		$card_info .= '<div class="wms-col-6">';
		$card_info .= '<label class="mylabel">' . esc_html__('Last Name', 'koala-multiple-customer-addresses') . '<span class="required">*</span></label>';
		$card_info .= '<input class="name_size" type="text" name="last_name_shipping">';
		$card_info .= '</div>';
		$card_info .= '</div>';
		$require_company_shipping = get_option('require_company_field_shipping');
		if ('1' === $require_company_shipping) {
			$card_info .= '<div class="wms-row">';
			$card_info .= '<div class="wms-col-12">';
			$card_info .= '<label class="mylabel">' . esc_html__('Company Name', 'koala-multiple-customer-addresses') . '<span class="required">*</span></label>';
			$card_info .= '<input class="inputsize" type="text" name="copmany_name_shipping_edit_required">';
			$card_info .= '</div>';
			$card_info .= '</div>';
		} else {
			$card_info .= '<div class="wms-row">';
			$card_info .= '<div class="wms-col-12">';
			$card_info .= '<label class="mylabel">' . esc_html__('Company Name', 'koala-multiple-customer-addresses') . '</label>';
			$card_info .= '<input class="inputsize" type="text" name="copmany_name_shipping">';
			$card_info .= '</div>';
			$card_info .= '</div>';
		}
		$card_info .= '<div class="wms-row">';
		$card_info .= '<div class="wms-col-6">';
		$card_info .= '<label class="mylabel">' . esc_html__('Choose Country', 'koala-multiple-customer-addresses') . '<span class="required">*</span></label>';
		$card_info .= '<select name="country_name_shipping" id="cor_countries_shipping_front">';

		$countr_obj = new WC_Countries();
		$countries  = $countr_obj->__get('countries');
		foreach ($countries as $key => $country) {
			$card_info .= '<option value="' . esc_html($key) . '">';
			$card_info .= esc_html__($country, 'koala-multiple-customer-addresses');
			$card_info .= '</option>';
		}
		$card_info .= '</select>';
		$card_info .= '</div>';
		$card_info .= '<div class="wms-col-6">';
		$card_info .= '<div class="state_val_add_shipping_front">';
		$card_info .= '</div>';
		$card_info .= '</div>';
		$card_info .= '</div>';
		$card_info .= '<div class="wms-row">';
		$card_info .= '<div class="wms-col-12">';
		$card_info .= '<label class="mylabel">' . esc_html__('Street Address', 'koala-multiple-customer-addresses') . '<span class="required">*</span></label>';
		$card_info .= '<input type="text" class="inputsize" name="st_address_shipping" placeholder="' . esc_html__('House number and street number', 'koala-multiple-customer-addresses') . '">';
		$card_info .= '</div>';
		$card_info .= '</div>';
		$card_info .= '<div class="wms-row">';
		$card_info .= '<div class="wms-col-12">';
		$card_info .= '<input type="text" class="inputsize" name="st_address_shipping2" placeholder="' . esc_html__('Apartment, suite, unit, etc.(optional)', 'koala-multiple-customer-addresses') . '">';
		$card_info .= '</div>';
		$card_info .= '</div>';
		$card_info .= '<div class="wms-row">';
		$card_info .= '<div class="wms-col-6">';
		$card_info .= '<label class="mylabel">' . esc_html__('Town/City', 'koala-multiple-customer-addresses') . '<span class="required">*</span></label>';
		$card_info .= '<input class="inputsize" type="text" name="town_address_shipping" placeholder="">';
		$card_info .= '</div>';
		$card_info .= '<div class="wms-col-6">';
		$card_info .= '<label class="mylabel">' . esc_html__('Postal code', 'koala-multiple-customer-addresses') . '<span class="required">*</span></label>';
		$card_info .= '<input class="inputsize" type="text" name="pin_code_shipping" placeholder="">';
		$card_info .= '</div>';
		$card_info .= '</div>';

		$add_shipping_phone = get_option('add_shipping_phone_option');

		$card_info .= '<div class="wms-row">';
		if ('1' === $add_shipping_phone) {
			$require_phone = get_option('require_shipping_phone');
			if ('1' === $require_phone) {
				$card_info .= '<div class="wms-row">';
				$card_info .= '<div class="wms-col-6">';
				$card_info .= '<label class="mylabel">' . esc_html__('Phone', 'koala-multiple-customer-addresses') . '<span class="required">*</span></label>';
				$card_info .= '<input class="inputsize" type="number" name="phone_shipping_required" placeholder="">';
				$card_info .= '</div>';
			} else {
				$card_info .= '<div class="wms-col-6">';
				$card_info .= '<label class="mylabel">' . esc_html_e('Phone', 'koala-multiple-customer-addresses') . '</label>';
				$card_info .= '<input class="inputsize" type="number" name="phone_shipping" placeholder="">';
				$card_info .= '</div>';
			}
		}
		$add_shipping_email = get_option('add_shipping_email_option');
		if ('1' === $add_shipping_email) {
			$require_email = get_option('require_shipping_email');
			if ('1' === $require_email) {
				$card_info .= '<div class="wms-col-6">';
				$card_info .= '<label class="mylabel">' . esc_html__('Email Address', 'koala-multiple-customer-addresses') . '<span class="required">*</span></label>';
				$card_info .= '<input class="inputsize" type="Email" name="email_shipping_required" placeholder="">';
				$card_info .= '</div>';
				$card_info .= '</div>';
			} else {
				$card_info .= '<div class="wms-col-6">';
				$card_info .= '<label class="mylabel">' . esc_html_e('Email Address', 'koala-multiple-customer-addresses') . '</label>';
				$card_info .= '<input class="inputsize" type="Email" name="email_shipping" placeholder="">';
				$card_info .= '</div>';
			}
		}
		$card_info .= '</div>';
		$card_info .= '<input type="hidden" name="user_id" value="' . esc_attr(get_current_user_id()) . '">';
		$card_info .= '<div align="right"><input type="button" class="buttonstyle cart_shipping_values" name="shipping_form_submit_front" value="Save"></div>';
		$card_info .= '</div>';
		$card_info .= '</div>';
		if (isset($user_id) && 0 !== $user_id) {
		$role = current(wp_get_current_user()->roles);
			if (( is_array($select_user_from_switch) && in_array($role, (array) $select_user_from_switch) ) || empty($select_user_from_switch)) {
				$wmsa_disable_bill = get_option('enable_disable_billing');
				if ('1' !== $wmsa_disable_bill) {
					$user_id = get_current_user_id();
					$all_shipping = get_user_meta($user_id, 'all_billing_address', true);
					$card_billing = ''; // Ensure initialization
					$card_billing .= '<div id="refresh_bill">';
					if (!empty($all_shipping)) {
						$card_billing .= '<h4>';
						$billing_checkout = get_option('billing_checkout_heading');
						if (isset($billing_checkout)) {
							$card_billing .= esc_attr($billing_checkout);
						}
						$card_billing .= '</h4>';
						$card_billing .= '<div id="find_val" class="find_val">';
						$card_billing .= '<input type="hidden" name="get_user_id" value="' . esc_attr($user_id) . '">';
						$card_billing .= '<select id="onchange_billing">';
						$select_label = get_option('default_select_key_field');
						if (!empty($select_label)) {
							$card_billing .= '<option>' . esc_attr($select_label) . '</option>';
						} else {
							$card_billing .= '<option>' . esc_html__('Select an address', 'koala-multiple-customer-addresses') . '</option>';
						}
						foreach ($all_shipping as $key => $value) {
							// Check if the key exists before accessing it
							$address_identifier_billing = isset($value['address_identifier_billing']) ? esc_attr($value['address_identifier_billing']) : 'Unknown';
							$card_billing .= '<option name="get_key" class="get_address_key" value="' . esc_attr($key) . '" ' . selected($key, $selected_data, false) . '>' . $address_identifier_billing . '</option>';
						}
						$card_billing .= '</select><br>';

						$hide_add_new_check_bill = get_option('hide_add_new_check_bill');
						if ('1' !== $hide_add_new_check_bill) {
							$get_val = get_option('enable_disable_billing');
							if ('1' !== $get_val) {
								$diable_cap = get_option('disable_user_add_del_billing');
								if ('1' !== $diable_cap) {
									$max_addresses = get_option('max_num_billing');
									if (!empty($max_addresses) && 0 !== $max_addresses) {
										$all_shipping_add = get_user_meta($user_id, 'all_billing_address', true);
										$count = 0;
										if (isset($all_shipping_add)) {

											foreach ($all_shipping_add as $key_b => $value) {
												++$count;
											}
										}

										if ($count < $max_addresses) {
											$billing_label = get_option('billing_title_key_field');
											if (empty($billing_label)) {
												$billing_title = 'Add New Billing Address';
											} else {
												$billing_title = $billing_label;
											}
											$card_billing .= '<a class="chk_a_style" id="add_cart_billing" name="cart_billing_model">' . esc_html__($billing_title, 'koala-multiple-customer-addresses') . '</a>';
										}
									} else {
										$billing_label = get_option('billing_title_key_field');
										if (empty($billing_label)) {
											$billing_title = 'Add New Billing Address';
										} else {
											$billing_title = $billing_label;
										}
										$card_billing .= '<a class="chk_a_style" id="add_cart_billing" name="cart_billing_model">' . esc_html__($billing_title, 'koala-multiple-customer-addresses') . '</a>';
									}
								}
							}
						}
						$card_billing .= '</div>';
					} else {
						$hide_add_new_check_bill = get_option('hide_add_new_check_bill');
						if ('1' !== $hide_add_new_check_bill) {
							$get_val = get_option('enable_disable_billing');
							if ('1' !== $get_val) {
								$diable_cap = get_option('disable_user_add_del_billing');
								if ('1' !== $diable_cap) {
									$max_addresses = get_option('max_num_billing');
									if (!empty($max_addresses) && 0 !== $max_addresses) {
										$all_shipping_add = get_user_meta($user_id, 'all_billing_address', true);
										$count = 0;
										if (!empty($all_shipping_add)) {
											foreach ($all_shipping_add as $key_b => $value) {
												++$count;
											}
										}
										if ($count < $max_addresses) {
											$billing_label = get_option('billing_title_key_field');
											if (empty($billing_label)) {
												$billing_title = 'Add New Billing Address';
											} else {
												$billing_title = $billing_label;
											}
											$card_billing .= '<a class="chk_a_style" id="add_cart_billing" name="cart_billing_model">' . esc_html__($billing_title, 'koala-multiple-customer-addresses') . '</a>';
										}
									} else {
										$billing_label = get_option('billing_title_key_field');
										if (empty($billing_label)) {
											$billing_title = 'Add New Billing Address';
										} else {
											$billing_title = $billing_label;
										}
										$card_billing .= '<a class="chk_a_style" id="add_cart_billing" name="cart_billing_model">' . esc_html__($billing_title, 'koala-multiple-customer-addresses') . '</a>';
									}
								}
							}
						}
					}
					$card_billing .= '</div>';
				}
			}
		}
		$card_billing .= ' <form method="post">';
					$card_billing .= '<div id="cart_modal_id" class="cart_model_class">';
					$card_billing .= '<div class="cart_model_content">';
					$card_billing .= '<span class="cart_m_exit">&times;</span>';
					$card_billing .= '<div class="message_billing"></div>';
					$getidentifier = get_option('disable_identifier_name');
		if ('1' !== $getidentifier) {
			$card_billing .= '<div class="wms-row">';
			$card_billing .= '<div class="wms-col-12">';
			$card_billing .= '<label class="mylabel">' . esc_html__('Identifier / Name', 'koala-multiple-customer-addresses') . '</label>';
			$card_billing .= '<span class="required">*</span>';
			$card_billing .= '<input placeholder="' . esc_html__('Office address', 'koala-multiple-customer-addresses') . '" class="inputsize" type="text" name="identifier_name_billing">';
			$card_billing .= '</div>';
			$card_billing .= '</div>';
		}

					$card_billing .= '<div class="wms-row">';
					$card_billing .= '<div class="wms-col-6">';
					$card_billing .= '<label class="mylabel">' . esc_html__('First Name', 'koala-multiple-customer-addresses') . '<span class="required">*</span></label>';
					$card_billing .= '<input class="name_size" type="text" name="first_name_billing">';
					$card_billing .= '</div>';
					$card_billing .= '<div class="wms-col-6">';
					$card_billing .= '<label class="mylabel">' . esc_html__('Last Name', 'koala-multiple-customer-addresses') . '<span class="required">*</span></label>';
					$card_billing .= '<input class="name_size" type="text" name="last_name_billing">';
					$card_billing .= '</div>';
					$card_billing .= '</div>';

					$require_company_billing = get_option('require_company_field_billing');
		if ('1' === $require_company_billing) {
			$card_billing .= '<div class="wms-row">';
			$card_billing .= '<div class="wms-col-12">';
			$card_billing .= '<label class="mylabel">' . esc_html__('Company Name', 'koala-multiple-customer-addresses') . '<span class="required">*</span></label>';
			$card_billing .= '<input class="inputsize" type="text" name="company_name_billing_required">';
			$card_billing .= '</div>';
			$card_billing .= '</div>';
		} else {
			$card_billing .= '<div class="wms-row">';
			$card_billing .= '<div class="wms-col-12">';
			$card_billing .= '<label class="mylabel">' . esc_html__('Company Name', 'koala-multiple-customer-addresses') . '</label>';
			$card_billing .= '<input class="inputsize" type="text" name="company_name_billing">';
			$card_billing .= '</div>';
			$card_billing .= '</div>';
		}

					$card_billing .= '<div class="wms-row">';
					$card_billing .= '<div class="wms-col-6">';
					$card_billing .= '<label class="mylabel">' . esc_html__('Choose Country', 'koala-multiple-customer-addresses') . '<span class="required">*</span></label>';
					$card_billing .= '<select name="country_name_billing" id="cor_countries_billing_front">';

					$countr_obj = new WC_Countries();
					$countries  = $countr_obj->__get('countries');
		foreach ($countries as $key => $country) {
			$card_billing .= '<option value="' . esc_html($key) . '">';
			$card_billing .= esc_html__($country, 'koala-multiple-customer-addresses');
			$card_billing .= '</option>';
		}

					$card_billing .= '</select>';
					$card_billing .= '</div>';
					$card_billing .= '<div class="wms-col-6">';
					$card_billing .= '<div class="state_val_add_billing_front"></div>';
					$card_billing .= '</div>';
					$card_billing .= '</div>';

					$card_billing .= '<div class="wms-row">';
					$card_billing .= '<div class="wms-col-12">';
					$card_billing .= '<label class="mylabel">' . esc_html__('Street Address', 'koala-multiple-customer-addresses') . '<span class="required">*</span></label>';
					$card_billing .= '<input type="text" class="inputsize" id="st_address_billing" name="st_address_billing" placeholder="' . esc_html__('House number and street number', 'koala-multiple-customer-addresses') . '">';
					$card_billing .= '</div>';
					$card_billing .= '</div>';

					$card_billing .= '<div class="wms-row">';
					$card_billing .= '<div class="wms-col-12">';
					$card_billing .= '<input type="text" class="inputsize" name="st_address_billing2" placeholder="' . esc_html__('Apartment, suite, unit, etc.(optional)', 'koala-multiple-customer-addresses') . '">';
					$card_billing .= '</div>';
					$card_billing .= '</div>';

					$card_billing .= '<div class="wms-row">';
					$card_billing .= '<div class="wms-col-6">';
					$card_billing .= '<label class="mylabel">' . esc_html__('Town/City', 'koala-multiple-customer-addresses') . '<span class="required">*</span></label>';
					$card_billing .= '<input class="inputsize" type="text" name="town_address_billing" placeholder="">';
					$card_billing .= '</div>';
					$card_billing .= '<div class="wms-col-6">';
					$card_billing .= '<label class="mylabel">' . esc_html__('Postal code', 'koala-multiple-customer-addresses') . '<span class="required">*</span></label>';
					$card_billing .= '<input class="inputsize" type="text" name="postal_code_billing" placeholder="">';
					$card_billing .= '</div>';
					$card_billing .= '</div>';

					$card_billing .= '<div class="wms-row">';
					$card_billing .= '<div class="wms-col-6">';
					$card_billing .= '<label class="mylabel">' . esc_html__('Phone', 'koala-multiple-customer-addresses') . '<span class="required">*</span></label>';
					$card_billing .= '<input class="inputsize" type="number" name="phone_billing" placeholder="">';
					$card_billing .= '</div>';
					$card_billing .= '<div class="wms-col-6">';
					$card_billing .= '<label class="mylabel">' . esc_html__('Email Address', 'koala-multiple-customer-addresses') . '<span class="required">*</span></label>';
					$card_billing .= '<input class="inputsize" type="Email" name="email_billing" placeholder="">';
					$card_billing .= '</div>';
					$card_billing .= '</div>';

					$card_billing .= '<input type="hidden" name="user_id" value="' . esc_attr(get_current_user_id()) . '">';
					$card_billing .= '<div class="save_button1"><input type="button" class="buttonstyle cart_billing_values" name="cart_bill_save" value="Save"></div>';
					$card_billing .= '</div>';

					$card_billing .= '</div>';
					

					$card_billing .= '</form>';

		
		$afcf_block_data = array(
			'admin_url' => admin_url( 'admin-ajax.php' ),
			'address_html' => $html,
			'address_cart' => $card_detail,
			'address_info'=>$card_info,
			'address_billinginfo'=>$card_billing,

		);

		wp_localize_script( 'kgr-blocks-frontj', 'kgr_php_vars', $afcf_block_data );
	}

	/**
	 * Registers the main JS file required to add filters and Slot/Fills.
	add_cart_billing
	 */
	public function register_main_integration() {
		$script_path = '/build/index.js';
		$script_url  = plugins_url( $script_path, __FILE__ );
		$script_asset_path = __DIR__ . '/build/index.asset.php';
		$script_asset      = file_exists( $script_asset_path )
			? require $script_asset_path
			: array(
				'dependencies' => array(),
				'version'      => $this->get_file_version( $script_path ),
			);



		wp_register_script(
			'ka-mca-checkout-blocks-integration',
			$script_url,
			$script_asset['dependencies'],
			$script_asset['version'],
			true
		);
		wp_set_script_translations(
			'ka-mca-checkout-blocks-integration',
			'ka_mca_checkout_block',
			__DIR__ . '/languages'
		);
	}

	/**
	 * Returns an array of script handles to enqueue in the frontend context.
	 *
	 * @return string[]
	 */
	public function get_script_handles() {
		return array( 'ka-mca-checkout-blocks-integration', 'ka-mca-checkout-block-frontend' );
	}

	/**
	 * Returns an array of script handles to enqueue in the editor context.
	 *
	 * @return string[]
	 */
	public function get_editor_script_handles() {
		return array( 'ka-mca-checkout-blocks-integration', 'ka-mca-checkout-block-editor' );
	}

	/**
	 * An array of key, value pairs of data made available to the block on the client side.
	 *
	 * @return array
	 */
	public function get_script_data() {
	}

	
	public function register_ka_mca_upload_file_block__block_editor_scripts() {
		$script_path       = '/build/ka-mca-checkout-block.js';
		$script_url        = plugins_url( $script_path, __FILE__ );
		$script_asset_path = __DIR__ . '/build/ka-mca-checkout-block.asset.php';
		$script_asset      = file_exists( $script_asset_path )
			? require $script_asset_path
			: array(
				'dependencies' => array(),
				'version'      => $this->get_file_version( $script_asset_path ),
			);

		wp_register_script(
			'ka-mca-checkout-block-editor',
			$script_url,
			$script_asset['dependencies'],
			$script_asset['version'],
			true
		);

		wp_set_script_translations(
			'ka-mca-checkout-block-editor',
			'ka_mca_checkout_block',
			__DIR__ . '/languages'
		);
	}

	

	public function register_ka_mca_upload_file_block__block_frontend_scripts() {
		$script_path       = '/build/ka-mca-checkout-block-frontend.js';
		$script_url        = plugins_url( $script_path, __FILE__ );
		$script_asset_path = __DIR__ . '/build/ka-mca-checkout-block-frontend.asset.php';
		$script_asset      = file_exists( $script_asset_path )
			? require $script_asset_path
			: array(
				'dependencies' => array(),
				'version'      => $this->get_file_version( $script_asset_path ),
			);

		wp_register_script(
			'ka-mca-checkout-block-frontend',
			$script_url,
			$script_asset['dependencies'],
			$script_asset['version'],
			true
		);
		wp_set_script_translations(
			'ka-mca-checkout-block-frontend',
			'ka_mca_checkout_block',
			__DIR__ . '/languages'
		);
	}

	/**
	 * Get the file modified time as a cache buster if we're in dev mode.
	 *
	 * @param string $file Local path to the file.
	 * @return string The cache buster value to use for the given file.
	 */
	protected function get_file_version( $file ) {
		if ( defined( 'SCRIPT_DEBUG' ) && SCRIPT_DEBUG && file_exists( $file ) ) {
			return filemtime( $file );
		}
		return KA_MULTIPLE_CUSTOMER_BLOCK_VERSION;
	}
}
